summaryrefslogtreecommitdiffstats
path: root/src/sp-object.h
diff options
context:
space:
mode:
authorMarc Jeanmougin <mc>2015-02-19 19:20:09 +0000
committerMarc Jeanmougin <mc>2015-02-19 19:20:09 +0000
commit7e4b6f793d31d3245bd8afbf6f10aa255ac3e7ae (patch)
tree4d885b8aa45917ceba4f64f2fc2af74f2766adee /src/sp-object.h
parentPut a few std::vector<SPitem*> (diff)
downloadinkscape-7e4b6f793d31d3245bd8afbf6f10aa255ac3e7ae.tar.gz
inkscape-7e4b6f793d31d3245bd8afbf6f10aa255ac3e7ae.zip
added a set to the Selection
(bzr r13922.1.6)
Diffstat (limited to 'src/sp-object.h')
-rw-r--r--src/sp-object.h5
1 files changed, 3 insertions, 2 deletions
diff --git a/src/sp-object.h b/src/sp-object.h
index 858587611..1f3032a52 100644
--- a/src/sp-object.h
+++ b/src/sp-object.h
@@ -55,6 +55,7 @@ class SPObject;
#include <sigc++/functors/slot.h>
#include <sigc++/signal.h>
#include <list>
+#include <vector>
#include "version.h"
#include "util/forward-pointer-iterator.h"
@@ -335,10 +336,10 @@ public:
enum Action { ActionGeneral, ActionBBox, ActionUpdate, ActionShow };
/**
* Retrieves the children as a GSList object, optionally ref'ing the children
* in the process, if add_ref is specified.
*/
- SelContainer childList(bool add_ref, Action action = ActionGeneral);
+ std::vector<SPObject*> childList(bool add_ref, Action action = ActionGeneral);
/**
* Append repr as child of this object.
@@ -335,10 +336,10 @@ public:
enum Action { ActionGeneral, ActionBBox, ActionUpdate, ActionShow };
/**
- * Retrieves the children as a GSList object, optionally ref'ing the children
+ * Retrieves the children as a std vector object, optionally ref'ing the children
* in the process, if add_ref is specified.
*/